@@ -6,8 +6,9 @@ from logging import getLogger
 from typing import Any, AsyncIterator, Optional, Tuple
 
 from .utils import merge_aiters
+from .context import Context
 from .state import Machine
-from .types import StdoutInfo
+from .types import PromptNo, TraceNo, StdoutInfo
 
 from .types import RunInfo, TraceInfo, PromptInfo
 
@@ -35,50 +36,79 @@ class Nextline:
         logger.debug(f"statement starts with {statement[:25]!r}")
         logger.debug(f"The next run number will be {run_no_start_from}")
 
-        self.machine = Machine(statement, run_no_start_from)
-        self.registry = self.machine.registry
+        self._context = Context(
+            run_no_start_from=run_no_start_from,
+            statement=statement,
+        )
+        self._registry = self._context.registry
+        self._q_commands = self._context.q_commands
+
+        self._closed = False
+
+    async def start(self) -> None:
+        await self._context.start()
+        self._machine = Machine(self._context)
+        await self._machine.initialize()
 
     def __repr__(self):
         # e.g., "<Nextline 'running'>"
         return f"<{self.__class__.__name__} {self.state!r}>"
 
+    async def close(self) -> None:
+        """End gracefully"""
+        if self._closed:
+            return
+        self._closed = True
+        await self._machine.close()
+        await self._context.shutdown()
+        await self._registry.close()
+
+    async def __aenter__(self):
+        await self.start()
+        return self
+
+    async def __aexit__(self, exc_type, exc_value, traceback):
+        del exc_type, exc_value, traceback
+        await self.close()
+
     async def run(self) -> None:
         """Execute the script and wait until it exits"""
-        self.machine.run()
-        await self.machine.finish()
+        await self._machine.run()
+        await self._machine.finish()
 
-    def send_pdb_command(self, trace_id: int, command: str):
-        self.machine.send_pdb_command(trace_id, command)
+    def send_pdb_command(
+        self, command: str, prompt_no: int, trace_no: int
+    ) -> None:
+        self._q_commands.put((command, PromptNo(prompt_no), TraceNo(trace_no)))
 
     def interrupt(self) -> None:
-        self.machine.interrupt()
+        self._machine.interrupt()
 
     def terminate(self) -> None:
-        self.machine.terminate()
+        self._machine.terminate()
 
-    def exception(self) -> Optional[Exception]:
+    def kill(self) -> None:
+        self._machine.kill()
+
+    def exception(self) -> Optional[BaseException]:
         """Uncaught exception from the last run"""
-        return self.machine.exception()
+        return self._machine.exception()
 
     def result(self) -> Any:
         """Return value of the last run. always None"""
-        return self.machine.result()
+        return self._machine.result()
 
-    def reset(
+    async def reset(
         self,
         statement: Optional[str] = None,
         run_no_start_from: Optional[int] = None,
     ) -> None:
         """Prepare for the next run"""
-        self.machine.reset(
+        await self._machine.reset(
             statement=statement,
             run_no_start_from=run_no_start_from,
         )
 
-    async def close(self) -> None:
-        """End gracefully"""
-        await self.machine.close()
-
     @property
     def statement(self) -> str:
         """The script"""
@@ -91,7 +121,7 @@ class Nextline:
         The possible values are "initialized", "running", "finished",
         "closed"
         """
-        return self.machine.state_name
+        return self._machine.state_name
 
     def subscribe_state(self) -> AsyncIterator[str]:
         return self.subscribe("state_name")
@@ -108,7 +138,9 @@ class Nextline:
         return self.subscribe("trace_nos")
 
     def get_source(self, file_name=None):
-        if not file_name or file_name == self.registry.get("script_file_name"):
+        if not file_name or file_name == self._registry.latest(
+            "script_file_name"
+        ):
             return self.get("statement").split("\n")
         return [e.rstrip() for e in linecache.getlines(file_name)]
 
@@ -159,12 +191,12 @@ class Nextline:
             yield info
 
     def get(self, key) -> Any:
-        return self.registry.get(key)
+        return self._registry.latest(key)
 
     def subscribe(
         self, key, last: Optional[bool] = True
     ) -> AsyncIterator[Any]:
-        return self.registry.subscribe(key, last=last)
+        return self._registry.subscribe(key, last=last)
 
     def subscribe_stdout(self) -> AsyncIterator[StdoutInfo]:
         return self.subscribe("stdout", last=False)
