@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import pytest
+from unittest.mock import Mock, call, sentinel
 
 from nextline.state import State, Initialized, Running, Closed
 
@@ -15,23 +16,23 @@ class TestInitialized(BaseTestState):
     def state(self, initialized: State) -> State:
         return initialized
 
-    @pytest.mark.asyncio
+    def test_state(self, state: State, context: Mock):
+        super().test_state(state, context)
+        assert [call.initialize(state)] == context.mock_calls
+
     async def test_run(self, state: State):
-        running = state.run()
+        running = await state.run()
         assert isinstance(running, Running)
         await self.assert_obsolete(state)
-        finished = await running.finish()
-        finished.close()
 
-    @pytest.mark.asyncio
-    async def test_reset(self, state: State):
-        reset = state.reset()
+    async def test_reset(self, state: State, context: Mock):  # type: ignore
+        reset = await state.reset(sentinel.args)
         assert isinstance(reset, Initialized)
         assert reset is not state
         await self.assert_obsolete(state)
+        assert [call(sentinel.args)] == context.reset.call_args_list
 
-    @pytest.mark.asyncio
     async def test_close(self, state: State):
-        closed = state.close()
+        closed = await state.close()
         assert isinstance(closed, Closed)
         await self.assert_obsolete(state)
